Index: base/test/test_support_android.cc |
diff --git a/base/test/test_support_android.cc b/base/test/test_support_android.cc |
index 4507ae4647f34dde5b3f7393234398359efbe3b6..f8441bd1ba5f9d75fe8e52258c6d339f24763514 100644 |
--- a/base/test/test_support_android.cc |
+++ b/base/test/test_support_android.cc |
@@ -17,8 +17,6 @@ |
#include "base/test/multiprocess_test.h" |
namespace { |
- |
-base::FilePath* g_test_data_dir = nullptr; |
struct RunState { |
RunState(base::MessagePump::Delegate* delegate, int run_depth) |
@@ -134,14 +132,13 @@ |
return std::unique_ptr<base::MessagePump>(new MessagePumpForUIStub()); |
}; |
// Provides the test path for DIR_SOURCE_ROOT and DIR_ANDROID_APP_DATA. |
bool GetTestProviderPath(int key, base::FilePath* result) { |
switch (key) { |
- case base::DIR_ANDROID_APP_DATA: |
- case base::DIR_SOURCE_ROOT: |
- CHECK(g_test_data_dir != nullptr); |
- *result = *g_test_data_dir; |
- return true; |
+ case base::DIR_ANDROID_APP_DATA: { |
+ // For tests, app data is put in external storage. |
+ return base::android::GetExternalStorageDirectory(result); |
+ } |
default: |
return false; |
} |
@@ -169,13 +166,8 @@ |
false); // Tick count |
} |
-void InitAndroidTestPaths(const FilePath& test_data_dir) { |
- if (g_test_data_dir) { |
- CHECK(test_data_dir == *g_test_data_dir); |
- return; |
- } |
- g_test_data_dir = new FilePath(test_data_dir); |
- InitPathProvider(DIR_SOURCE_ROOT); |
+void InitAndroidTestPaths() { |
+ InitPathProvider(DIR_MODULE); |
InitPathProvider(DIR_ANDROID_APP_DATA); |
} |
@@ -187,6 +179,7 @@ |
void InitAndroidTest() { |
if (!base::AndroidIsChildProcess()) { |
InitAndroidTestLogging(); |
+ InitAndroidTestPaths(); |
} |
InitAndroidTestMessageLoop(); |
} |
@@ -134,14 +132,13 @@ |
return std::unique_ptr<base::MessagePump>(new MessagePumpForUIStub()); |
}; |
-// Provides the test path for DIR_SOURCE_ROOT and DIR_ANDROID_APP_DATA. |
+// Provides the test path for DIR_MODULE and DIR_ANDROID_APP_DATA. |
bool GetTestProviderPath(int key, base::FilePath* result) { |
switch (key) { |